## MOMIA2 (Mycobacteria-optimized microscopy image analysis v.2) ##

### Installation guide: ###

Install miniconda and create a new conda environment
```
conda create --name myenv python=3.11
```

Need to first install pyqt5 from conda (pip doesn't always work)
```
conda install -c anaconda pyqt
```

To install **momia2** from pip:
```
pip install momia2
```

To install the most up-to-date version in development, run:
```
pip install git+https://github.com/jzrolling/CleanSpace.git
```




